aboutsummaryrefslogtreecommitdiffhomepage
path: root/generic/pg-response.el
diff options
context:
space:
mode:
authorGravatar David Aspinall <da@inf.ed.ac.uk>2008-01-15 18:48:11 +0000
committerGravatar David Aspinall <da@inf.ed.ac.uk>2008-01-15 18:48:11 +0000
commita7d81a3e024a05a45fd55a385e27bf003de245f9 (patch)
tree41eb7a4b69746f9d89a492080cbb2fc2b8fefaaa /generic/pg-response.el
parent776627a70a4403313505f6ac71538fb700693fa6 (diff)
pg-response-display: use add-text-properties instead of font-lock-append-text-property [no behaviour change]
Diffstat (limited to 'generic/pg-response.el')
-rw-r--r--generic/pg-response.el9
1 files changed, 4 insertions, 5 deletions
diff --git a/generic/pg-response.el b/generic/pg-response.el
index b9d2e5cc..ec655b41 100644
--- a/generic/pg-response.el
+++ b/generic/pg-response.el
@@ -332,12 +332,11 @@ Returns non-nil if response buffer was cleared."
(proof-fontify-region start (point))
;; This is one reason why we don't keep the buffer in font-lock
;; minor mode: it destroys this hacky property as soon as it's
;; made! (Using the minor mode is much more convenient, tho')
(if (and face proof-output-fontify-enable)
- (font-lock-append-text-property
- start (point-max) 'face face))
+ (add-text-properties
+ start (point-max) (list 'face face)))
(set-buffer-modified-p nil))))))
@@ -332,12 +332,11 @@ Returns non-nil if response buffer was cleared."
(proof-fontify-region start (point))
- ;; This is one reason why we don't keep the buffer in font-lock
- ;; minor mode: it destroys this hacky property as soon as it's
- ;; made! (Using the minor mode is much more convenient, tho')
+ ;; Fontify message: one reason why we don't keep the buffer in
+ ;; font-lock minor mode is these properties would be lost.
(if (and face proof-output-fontify-enable)